@@ -15,7 +15,7 @@ class color:
 
 class chop:
 	 x_coder = f"""{color.bold}
-{color.white} [⏦] - {color.cyan} 𝐋𝐈𝐁𝐑𝐀𝐑𝐘𝐒𝐇𝐀𝐃 {color.yellow} 𝐕𝐄𝐑𝐒𝐈𝐎𝐍  {color.red}1.0.0    
+{color.white} [⏦] - {color.cyan} 𝐋𝐈𝐁𝐑𝐀𝐑𝐘𝐒𝐇𝐀𝐃 {color.yellow} 𝐕𝐄𝐑𝐒𝐈𝐎𝐍  {color.red}1.0.3    
 
 {color.white} [⏦] - {color.cyan} 𝐋𝐈𝐁𝐑𝐀𝐑𝐘𝐒𝐇𝐀𝐃 {color.yellow} 𝐂𝐎𝐏𝐘𝐑𝐈𝐆𝐇𝐓 (𝐂) {color.red} 2022 {color.green}𝐌𝐀𝐌𝐀𝐃 𝐂𝐎𝐃𝐄𝐑   
 
@@ -25,12 +25,3 @@ class chop:
 """
 	 print(x_coder)
       
-for x in range(3):
-    for i in ("⢿", "⣻", "⣽", "⣾", "⣷", "⣯", "⣟", "⡿"):
-        sleep(0.1)
-        if x == 10:
-            print('',end='')
-            break
-        else:
-            print( color.blue+'   𝐋𝐈𝐁𝐑𝐀𝐑𝐘 𝐒𝐇𝐀𝐃 𝐑𝐔𝐍𝐈𝐍𝐆 𝐏𝐋𝐄𝐀𝐒𝐄 𝐖𝐀𝐈𝐓   ',color.green+i,end='\r')
-print(color.white+"\n")
